{% extends "sphene/sphwiki/base.html" %} {% load i18n %} {% load sph_extras %} {% load sph_pagination %} {% block content %} {% include "sphene/sphwiki/_snip_header.html" %}

{% trans "Back to Snip" %}

{% trans "Date" %} | {% trans "Editor" %} | {% trans "Changes" %} | {% trans "Change Message" %} {% if snip.has_edit_permission %} | {% trans "Edit" %} {% endif %}
--- | --- | --- | --- | ---
{% trans "Body" %} | {% trans "Title" %} | {% trans "Tags" %}
{% for change in object_list %}
{{ change.edited|sph_date }} | {% sph_html_user change.editor %} | {% if change.body_changed %}X{% endif %} | {% if change.title_changed %}X{% endif %} | {% if change.tags_changed %}X{% endif %} | {{ change.message }} {% if snip.has_edit_permission %} | {% trans "Edit this version" %} {% endif %}
{% endfor %}

{% if is_paginated %} {% blocktrans with hits as changecount %}{{ changecount }} Changes.{% endblocktrans %} {% sph_pagination pages page %} {% else %} {% blocktrans with object_list.count as changecount %}{{ changecount }} Changes.{% endblocktrans %} {% endif %} {% endblock %}